@@ -1,20 +1,20 @@
 MapGAM.version = function() cat('
-Jul 24 2018 	MapGAM version 1.2
+Jan 21 2019 	MapGAM version 1.2-4
   	
 Dec 10 2016	AIC.modgam.R
-Jul 24 2018	MapGAM.version.R
+Jan 21 2019	MapGAM.version.R
 Dec 10 2016	coef.gamcox.R
 Dec 10 2016	coef.modgam.R
 Jul 24 2018	colormap.R
 Oct 16 2016	dls.R
 Dec 10 2016	formula.gamcox.R
 Dec 10 2016	formula.modgam.R
-Feb 6 2017	gamcox.R
-Oct 16 2016	gamcox.fit.R
+Oct 31 2018	gamcox.R
+Oct 30 2018	gamcox.fit.R
 Oct 8 2017	modgam.R
 Sep 15 2017	mypredict.gam.R
-Apr 9 2018	optspan.R
-Nov 20 2016	plot.modgam.R
+Oct 31 2018	optspan.R
+Jan 21 2019	plot.modgam.R
 Oct 16 2016	predgrid.R
 Oct 20 2016	predict.gamcox.R
 Dec 8 2016	print.gamcox.R
